==> dante-1.1.10.tar.gz: dante-1.1.10/sockd/auth_password.c <==
/*
 * Copyright (c) 1997, 1998, 1999, 2000, 2001
 *      Inferno Nettverk A/S, Norway.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. The above copyright notice, this list of conditions and the following
 *    disclaimer must appear in all copies of the software, derivative works
 *    or modified versions, and any portions thereof, aswell as in all
 *    supporting documentation.
 * 2. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by
 *      Inferno Nettverk A/S, Norway.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Inferno Nettverk A/S requests users of this software to return to
 *
 *  Software Distribution Coordinator  or  sdc@inet.no
 *  Inferno Nettverk A/S
 *  Oslo Research Park
 *  Gaustadallen 21
 *  NO-0349 Oslo
 *  Norway
 *
 * any improvements or extensions that they make and grant Inferno Nettverk A/S
 * the rights to redistribute these changes.
 *
 */

#include "common.h"

static const char rcsid[] =
"$Id: auth_password.c,v 1.3 2001/05/13 14:26:49 michaels Exp $";

int
passwordcheck(name, clearpassword, emsg, emsglen)
	const char *name;
	const char *clearpassword;
	char *emsg;
	size_t emsglen;
{
/*	const char *function = "passwordcheck()"; */
	struct passwd *pw;
	char *salt, *password;
	uid_t euid;

	socks_seteuid(&euid, config.uid.privileged);
	pw = socks_getpwnam(name);
	socks_reseteuid(config.uid.privileged, euid);

	if (pw == NULL) {
		snprintfn(emsg, emsglen, "system password userlookup failed");
 		return -1; /* XXX waste cycles correctly? */
	}

	if (clearpassword != NULL) {
		salt		= pw->pw_passwd;
		password = pw->pw_passwd;

		if (strcmp(crypt(clearpassword, salt), password) == 0)
			return 0;
		else {
			snprintfn(emsg, emsglen, "system password userauthentication failed");
			return -1;
		}
	}
	
	return -1;
}

==> dante-1.1.11.tar.gz: dante-1.1.11/sockd/auth_password.c <==
/*
 * Copyright (c) 1997, 1998, 1999, 2000, 2001
 *      Inferno Nettverk A/S, Norway.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. The above copyright notice, this list of conditions and the following
 *    disclaimer must appear in all copies of the software, derivative works
 *    or modified versions, and any portions thereof, aswell as in all
 *    supporting documentation.
 * 2. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *      This product includes software developed by
 *      Inferno Nettverk A/S, Norway.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Inferno Nettverk A/S requests users of this software to return to
 *
 *  Software Distribution Coordinator  or  sdc@inet.no
 *  Inferno Nettverk A/S
 *  Oslo Research Park
 *  Gaustadallen 21
 *  NO-0349 Oslo
 *  Norway
 *
 * any improvements or extensions that they make and grant Inferno Nettverk A/S
 * the rights to redistribute these changes.
 *
 */

#include "common.h"

static const char rcsid[] =
"$Id: auth_password.c,v 1.4 2001/11/11 13:38:33 michaels Exp $";

int
passwordcheck(name, clearpassword, emsg, emsglen)
	const char *name;
	const char *clearpassword;
	char *emsg;
	size_t emsglen;
{
/*	const char *function = "passwordcheck()"; */
	struct passwd *pw;
	char *salt, *password;
	uid_t euid;

	socks_seteuid(&euid, socksconfig.uid.privileged);
	pw = socks_getpwnam(name);
	socks_reseteuid(socksconfig.uid.privileged, euid);

	if (pw == NULL) {
		snprintfn(emsg, emsglen, "system password userlookup failed");
 		return -1; /* XXX waste cycles correctly? */
	}

	if (clearpassword != NULL) {
		salt		= pw->pw_passwd;
		password = pw->pw_passwd;

		if (strcmp(crypt(clearpassword, salt), password) == 0)
			return 0;
		else {
			snprintfn(emsg, emsglen, "system password userauthentication failed");
			return -1;
		}
	}
	
	return -1;
}
